@@ -1,4 +1,5 @@
 stepEvolution <- function(X,Y,formula,P=1:7,K=10,test=NULL,graphic=TRUE){
+
 	if(!is.numeric(Y)){
 		stop("The response must be of class \'numeric\'.")
 	}
@@ -14,20 +15,29 @@ stepEvolution <- function(X,Y,formula,P=1:7,K=10,test=NULL,graphic=TRUE){
 	if(nTerms>n){
 		stop("There are too many terms into the full length model")
 	}
-	R2criterion <- vector('numeric',length=length(P))
-	Q2criterion <- vector('numeric',length=length(P))
-	RMSEcriterion <- vector('numeric',length=length(P))
-	ModelSize	<- vector('numeric',length=length(P))
+
+	m	 <- length(P)
+        
+	ModelSize	<- vector('numeric',length=m)
+	R2criterion     <- vector('numeric',length=m)
 	
 	if(!is.null(test)){
+
 	  test <- data.frame(test)
+
 	  if (dim(test)[2]!=(f+1)){
 	    test <- NULL
 	  }
-	  R2testcriterion <- vector('numeric',length=length(P))
-	}
 
-	m	 <- length(P)
+	  R2testcriterion <- vector('numeric',length=m)
+
+	} else {
+
+	  Q2criterion <- vector('numeric',length=m)
+	  RMSEcriterion <- vector('numeric',length=m)
+
+        }
+
 
 	if(graphic==TRUE){
 	  plot(NA, xlim=c(0,1), ylim=c(0,1), axes = FALSE,xlab='',ylab='',main="Selected variables during stepwise procedure",cex=1.3)
@@ -54,46 +64,71 @@ stepEvolution <- function(X,Y,formula,P=1:7,K=10,test=NULL,graphic=TRUE){
 					col = 'blue')
   		   }
 		}
+
   		R2criterion[p]	<- R2(Y,smodel$model$fitted.values)
-		tmp <- crossValidation(smodel,K=K)
-		Q2criterion[p]	<- tmp$Q2
-		RMSEcriterion[p] <- tmp$RMSE_CV
 		ModelSize[p]	<- smodel$model$rank-1
+
 		if(!is.null(test)){
+
 		  Xtest	<- test[,1:f]
 		  Ytest	<- test[,f+1]
 		  YStep	<- modelPredict(smodel,newdata=Xtest)
 		  R2testcriterion[p]	<- R2(Ytest,YStep)
+
+		} else {
+
+  		  tmp <- crossValidation(smodel,K=K)
+		  Q2criterion[p]    <- tmp$Q2
+		  RMSEcriterion[p]  <- tmp$RMSE_CV
+
 		}
 	}
 
 	if(graphic==TRUE){
 		if(is.null(test)){
 		  m = min(R2criterion,Q2criterion); M=max(R2criterion,Q2criterion);
-		  op <- par(ask=TRUE,mfrow = c(2, 2), oma=c(0,0,3,0))
-		  plot(P,R2criterion,type='p',pch=19,xlab='Penalty parameter',ylab='R2',ylim=c(m,M))
-		  plot(P,Q2criterion,type='p',pch=17,col='green3',xlab='Penalty parameter',ylab='Q2 (K=10)', ylim=c(m,M))
-		  plot(P,R2criterion,type='p',pch=19,xlab='Penalty parameter',ylab='',ylim=c(m,M))
-		  lines(P,Q2criterion,type='p',pch=17,col='green3')
-		  legend("bottomleft",legend=c("R2","Q2 (K=10)"),lty=0,pch=c(19,17),col=c("black","green3"),cex=0.7)
-		  plot(P,ModelSize,type='p',pch=19,col='violetred2',xlab='Penalty parameter',ylab='size of the fitted model')
+		  op <- par(ask=TRUE,mfrow = c(2, 2),oma=c(0,0,3,0))
+
+		  plot(P,R2criterion,type='b',pch=19,xlab='Penalty parameter',ylab='R2',ylim=c(m,M),xaxt="n")
+          	  axis(side=1,at=P)
+
+		  plot(P,Q2criterion,type='b',pch=17,col='green3',xlab='Penalty parameter',ylab='Q2 (K=10)', ylim=c(m,M),xaxt="n")
+          	  axis(side=1,at=P)
+
+		  plot(P,ModelSize,type='b',pch=19,col='violetred2',xlab='Penalty parameter',ylab='size of the fitted model',xaxt="n")
+                  axis(side=1,at=P)
+
 		  par(op)
 		  mtext("Stepwise: influence of the penalty parameter", side=3, line=0, font=1, cex=1.3)
+	          op <- par(ask=TRUE)
+                  plot(P,RMSEcriterion,type='b',pch=19,xlab='Penalty parameter',ylab='RMSE CV',main=paste("RMSE criterion for K=",K,"folds cross-validation"),xaxt="n")
+                  axis(side=1,at=P)
+                  par(op)
+
 		} else {
+
 		  op <- par(ask=TRUE,mfrow = c(2, 2), oma=c(0,0,3,0))
-		  m = min(R2criterion,Q2criterion,R2testcriterion)
-		  M=max(R2criterion,Q2criterion,R2testcriterion)
-		  plot(P,R2criterion,type='p',pch=19,xlab='Penalty parameter',ylab='R2',ylim=c(m,M))
-		  plot(P,Q2criterion,type='p',pch=17,col='green3',xlab='Penalty parameter',ylab='Q2 (K=10)', ylim=c(m,M))
-		  plot(P,R2testcriterion,type='p',pch=19,col='blue',xlab='Penalty parameter', ylab='R2test', ylim=c(m,M))
-		  plot(P,ModelSize,type='p',pch=19,col='violetred2',xlab='Penalty parameter',ylab='size of the fitted model')
+		  m = min(R2criterion,R2testcriterion)
+		  M = max(R2criterion,R2testcriterion)
+
+		  plot(P,R2criterion,type='b',pch=19,xlab='Penalty parameter',ylab='R2',ylim=c(m,M))
+		  plot(P,R2testcriterion,type='b',pch=19,col='blue',xlab='Penalty parameter', ylab='R2test', ylim=c(m,M))
+		  plot(P,ModelSize,type='b',pch=19,col='violetred2',xlab='Penalty parameter',ylab='size of the fitted model')
+
 		  par(op)
 		  mtext("Stepwise: influence of the penalty parameter", side=3, line=0, font=1, cex=1.3)
+
 		} 
 	}
-	plot(P,RMSEcriterion,type='b',pch=19,xlab='Penalty parameter',ylab='RMSE CV',main=paste("RMSE criterion for K=",K,"folds cross-validation"))
+
 
 	if(is.null(test)){
+
 	  return(list(penalty=P,m=ModelSize,R2=R2criterion,Q2=Q2criterion,RMSE_CV=RMSEcriterion))
-	} else return(list(penalty=P,m=ModelSize,R2=R2criterion,Q2=Q2criterion,R2test=R2testcriterion,RMSE_CV=RMSEcriterion))
+
+	} else {
+
+          return(list(penalty=P,m=ModelSize,R2=R2criterion,R2test=R2testcriterion))
+
+        }
 }
\ No newline at end of file
